SocialCrawler
=============

It is a python package to help get data from Twitter, Foursquare.

This package was created to facilitate the data mining from Twitter and
Foursquare.

Install (generic way)
---------------------

.. code:: shell

        $ python3 -m pip install SocialCrawler

How work ?
----------

Requeriments
^^^^^^^^^^^^

-  Python >= 3
-  setuptools
-  Foursquare developer credentials ( if you wanna work with)
-  Twitter developer credentials ( if you wanna work with )

